import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

var COLUMN_SIZES = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', 'three-quarters', 'two-thirds', 'half', 'one-third', 'one-quarter', 'four-fifths', 'three-fifths', 'two-fifths', 'one-fifth'];

var Column = function Column(_ref) {
  var _classNames;

  var children = _ref.children,
      className = _ref.className,
      isNarrow = _ref.isNarrow,
      isNarrowMobile = _ref.isNarrowMobile,
      isNarrowTablet = _ref.isNarrowTablet,
      isNarrowDesktop = _ref.isNarrowDesktop,
      offset = _ref.offset,
      offsetMobile = _ref.offsetMobile,
      offsetTablet = _ref.offsetTablet,
      offsetDesktop = _ref.offsetDesktop,
      offsetWidescreen = _ref.offsetWidescreen,
      offsetFullHD = _ref.offsetFullHD,
      size = _ref.size,
      sizeMobile = _ref.sizeMobile,
      sizeTablet = _ref.sizeTablet,
      sizeDesktop = _ref.sizeDesktop,
      sizeWidescreen = _ref.sizeWidescreen,
      sizeFullHD = _ref.sizeFullHD;
  return React.createElement(
    'div',
    {
      className: classNames('column', (_classNames = {
        'is-narrow': isNarrow,
        'is-narrow-mobile': isNarrowMobile,
        'is-narrow-tablet': isNarrowTablet,
        'is-narrow-desktop': isNarrowDesktop
      }, _classNames['is-offset-' + offset] = Boolean(offset), _classNames['is-offset-' + offsetMobile + '-mobile'] = Boolean(offsetMobile), _classNames['is-offset-' + offsetTablet + '-tablet'] = Boolean(offsetTablet), _classNames['is-offset-' + offsetDesktop + '-desktop'] = Boolean(offsetDesktop), _classNames['is-offset-' + offsetWidescreen + '-widescreen'] = Boolean(offsetWidescreen), _classNames['is-offset-' + offsetFullHD + '-fullhd'] = Boolean(offsetFullHD), _classNames['is-' + size] = Boolean(size), _classNames['is-' + sizeMobile + '-mobile'] = Boolean(sizeMobile), _classNames['is-' + sizeTablet + '-tablet'] = Boolean(sizeTablet), _classNames['is-' + sizeDesktop + '-desktop'] = Boolean(sizeDesktop), _classNames['is-' + sizeWidescreen + '-widescreen'] = Boolean(sizeWidescreen), _classNames['is-' + sizeFullHD + '-fullhd'] = Boolean(sizeFullHD), _classNames[className] = Boolean(className), _classNames))
    },
    children
  );
};

Column.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  isNarrow: PropTypes.bool,
  isNarrowMobile: PropTypes.bool,
  isNarrowTablet: PropTypes.bool,
  isNarrowDesktop: PropTypes.bool,
  /** Default offset size. Available values: View **Column Sizes** */
  offset: PropTypes.oneOf(COLUMN_SIZES),
  /** Mobile offset size (mobile as min breakpoint). Available values: View **Column Sizes** */
  offsetMobile: PropTypes.oneOf(COLUMN_SIZES),
  /** Tablet offset size (tablet as min breakpoint). Available values: View **Column Sizes** */
  offsetTablet: PropTypes.oneOf(COLUMN_SIZES),
  /** Desktop offset size (desktop as min breakpoint). Available values: View **Column Sizes** */
  offsetDesktop: PropTypes.oneOf(COLUMN_SIZES),
  /** Widescreen offset size (widescreen as min breakpoint). Available values: View **Column Sizes** */
  offsetWidescreen: PropTypes.oneOf(COLUMN_SIZES),
  /** Full HD offset size (fullhd as min breakpoint). Available values: View **Column Sizes** */
  offsetFullHD: PropTypes.oneOf(COLUMN_SIZES),
  /** Default size. Available values: View **Column Sizes** */
  size: PropTypes.oneOf(COLUMN_SIZES),
  /** Mobile size (mobile as min breakpoint). Available values: View **Column Sizes** */
  sizeMobile: PropTypes.oneOf(COLUMN_SIZES),
  /** Tablet size (tablet as min breakpoint). Available values: View **Column Sizes** */
  sizeTablet: PropTypes.oneOf(COLUMN_SIZES),
  /** Desktop size (desktop as min breakpoint). Available values: View **Column Sizes** */
  sizeDesktop: PropTypes.oneOf(COLUMN_SIZES),
  /** Widescreen size (widescreen as min breakpoint). Available values: View **Column Sizes** */
  sizeWidescreen: PropTypes.oneOf(COLUMN_SIZES),
  /** Full HD size (fullhd as min breakpoint). Available values: View **Column Sizes** */
  sizeFullHD: PropTypes.oneOf(COLUMN_SIZES)
} : {};

Column.defaultProps = {
  className: null,
  isNarrow: false,
  isNarrowMobile: false,
  isNarrowTablet: false,
  isNarrowDesktop: false,
  offset: null,
  offsetMobile: null,
  offsetTablet: null,
  offsetDesktop: null,
  offsetWidescreen: null,
  offsetFullHD: null,
  size: null,
  sizeMobile: null,
  sizeTablet: null,
  sizeDesktop: null,
  sizeWidescreen: null,
  sizeFullHD: null
};

export default Column;