var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Toggle from 'react-toggled';

import ClickOutside from '../utils/ClickOutside';
import NavbarDropdown from './NavbarDropdown';

var NavbarItem = function NavbarItem(_ref) {
  var children = _ref.children,
      className = _ref.className,
      dropdownTrigger = _ref.dropdownTrigger,
      Element = _ref.element,
      hasDropdown = _ref.hasDropdown,
      isActive = _ref.isActive,
      isDropdownInitiallyActive = _ref.isDropdownInitiallyActive,
      isDropup = _ref.isDropup,
      isHoverable = _ref.isHoverable,
      props = _objectWithoutProperties(_ref, ['children', 'className', 'dropdownTrigger', 'element', 'hasDropdown', 'isActive', 'isDropdownInitiallyActive', 'isDropup', 'isHoverable']);

  return React.createElement(
    Toggle,
    { defaultOn: isDropdownInitiallyActive },
    function (_ref2) {
      var _classNames;

      var _getProps = _ref2.getTogglerProps,
          on = _ref2.on,
          show = _ref2.setOn,
          hide = _ref2.setOff,
          toggle = _ref2.toggle;
      return React.createElement(
        Element,
        _extends({
          className: classNames('navbar-item', (_classNames = {
            'has-dropdown': hasDropdown,
            'is-active': on || isActive,
            'has-dropdown-up': isDropup,
            'is-hoverable': isHoverable
          }, _classNames[className] = Boolean(className), _classNames))
        }, props),
        hasDropdown && dropdownTrigger ? React.createElement(
          ClickOutside,
          { onClickOutside: hide },
          dropdownTrigger({
            getProps: function getProps() {
              return _getProps({ style: { height: '100%' } });
            },
            show: show,
            hide: hide,
            toggle: toggle
          }),
          React.createElement(
            NavbarDropdown,
            null,
            children
          )
        ) : children
      );
    }
  );
};

NavbarItem.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node.isRequired,
  className: PropTypes.string,
  dropdownTrigger: PropTypes.func,
  element: PropTypes.oneOfType([PropTypes.element, PropTypes.string]),
  /** If true, the navbar item consists of a dropdown */
  hasDropdown: PropTypes.bool,
  /** If true, the navbar item is active */
  isActive: PropTypes.bool,
  /** If true, the navbar item's dropdown is initially active */
  isDropdownInitiallyActive: PropTypes.bool,
  /** If true, the navbar item's dropdown is actually a dropup */
  isDropup: PropTypes.bool,
  /** If true, the dropdown is hoverable */
  isHoverable: PropTypes.bool
} : {};

NavbarItem.defaultProps = {
  className: null,
  dropdownTrigger: null,
  element: 'div',
  hasDropdown: false,
  isActive: false,
  isDropdownInitiallyActive: false,
  isDropup: false,
  isHoverable: false
};

export default NavbarItem;