var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import * as sharedPropTypes from '../_prop-types';

import Field from '../Field/Field';
import FieldBody from '../Field/FieldBody';
import FieldControl from '../Field/FieldControl';
import FieldLabel from '../Field/FieldLabel';

var SelectField = function SelectField(_ref) {
  var _classNames;

  var children = _ref.children,
      className = _ref.className,
      color = _ref.color,
      helpText = _ref.helpText,
      inputSize = _ref.inputSize,
      id = _ref.id,
      inputProps = _ref.inputProps,
      isDisabled = _ref.isDisabled,
      isHorizontal = _ref.isHorizontal,
      isLoading = _ref.isLoading,
      isMultiSelect = _ref.isMultiSelect,
      isRounded = _ref.isRounded,
      labelComponent = _ref.labelComponent,
      labelName = _ref.labelName,
      labelSize = _ref.labelSize,
      leftIconName = _ref.leftIconName,
      onBlur = _ref.onBlur,
      _onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      options = _ref.options,
      state = _ref.state,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['children', 'className', 'color', 'helpText', 'inputSize', 'id', 'inputProps', 'isDisabled', 'isHorizontal', 'isLoading', 'isMultiSelect', 'isRounded', 'labelComponent', 'labelName', 'labelSize', 'leftIconName', 'onBlur', 'onChange', 'onFocus', 'options', 'state', 'value']);

  return React.createElement(
    Field,
    _extends({ id: id, isHorizontal: isHorizontal, label: labelName, labelSize: labelSize }, props),
    (labelName || labelComponent) && React.createElement(
      FieldLabel,
      { isHorizontal: isHorizontal, isNormal: true, size: labelSize },
      labelName || labelComponent
    ),
    React.createElement(
      FieldBody,
      null,
      React.createElement(
        Field,
        { color: color, helpText: helpText },
        React.createElement(
          FieldControl,
          { leftIconName: leftIconName },
          React.createElement(
            'div',
            {
              className: classNames('select', (_classNames = {}, _classNames['is-' + color] = color, _classNames['is-' + inputSize] = inputSize, _classNames['is-loading'] = isLoading, _classNames['is-multiple'] = isMultiSelect, _classNames['is-rounded'] = isRounded, _classNames[className] = Boolean(className), _classNames)),
              disabled: isDisabled
            },
            React.createElement(
              'select',
              _extends({
                'aria-label': labelName,
                className: classNames(state ? 'is-' + state : ''),
                multiple: isMultiSelect,
                onBlur: onBlur,
                onChange: function onChange(e) {
                  return _onChange && _onChange(e.target.value, e);
                },
                onFocus: onBlur,
                value: value
              }, inputProps),
              options.map(function (option, i) {
                return (
                  /* eslint-disable react/no-array-index-key */
                  React.createElement(
                    'option',
                    { key: i, value: option.value },
                    option.label
                  )
                );
              })
            )
          )
        )
      )
    )
  );
};

SelectField.propTypes = process.env.NODE_ENV !== "production" ? {
  children: PropTypes.node,
  className: PropTypes.string,
  /** Color of input field. */
  color: sharedPropTypes.color,
  /** Displays help text */
  helpText: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  /** The label that appears above the input */
  labelComponent: PropTypes.element,
  /** The label that appears above the input */
  labelName: PropTypes.string,
  /** Size of the label field */
  labelSize: sharedPropTypes.size,
  /** Name of left field icon */
  leftIconName: PropTypes.string,
  /** ID for the input field */
  id: PropTypes.string,
  inputProps: PropTypes.object,
  /** Size of the input field */
  inputSize: sharedPropTypes.size,
  /** Disable the input field */
  isDisabled: PropTypes.bool,
  /** Input field is horizontal */
  isHorizontal: PropTypes.bool,
  /** Input field is loading */
  isLoading: PropTypes.bool,
  /** Enable multi-select */
  isMultiSelect: PropTypes.bool,
  /** Input field is rounded */
  isRounded: PropTypes.bool,
  /** Function to invoke on blur */
  onBlur: PropTypes.func,
  /** Function to invoke on change */
  onChange: PropTypes.func,
  /** Set of options to select from */
  options: PropTypes.array,
  /** Function to invoke on focus */
  onFocus: PropTypes.func,
  /** State of field */
  state: sharedPropTypes.state,
  /** Value of the input */
  value: PropTypes.string
} : {};

SelectField.defaultProps = {
  children: null,
  className: null,
  color: null,
  helpText: null,
  labelComponent: null,
  labelName: null,
  labelSize: null,
  leftIconName: null,
  id: null,
  inputProps: {},
  inputSize: null,
  isDisabled: false,
  isHorizontal: false,
  isLoading: false,
  isMultiSelect: false,
  isRounded: false,
  onBlur: null,
  onChange: null,
  options: [],
  onFocus: null,
  state: null,
  value: undefined
};

export default SelectField;