var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import TextareaAutosize from 'react-autosize-textarea';
import * as sharedPropTypes from '../_prop-types';

import Field from '../Field/Field';
import FieldBody from '../Field/FieldBody';
import FieldControl from '../Field/FieldControl';
import FieldLabel from '../Field/FieldLabel';

var TextAreaField = function TextAreaField(_ref) {
  var _classNames;

  var autoComplete = _ref.autoComplete,
      autoFocus = _ref.autoFocus,
      children = _ref.children,
      className = _ref.className,
      color = _ref.color,
      helpText = _ref.helpText,
      inputSize = _ref.inputSize,
      id = _ref.id,
      inputProps = _ref.inputProps,
      isDisabled = _ref.isDisabled,
      isLoading = _ref.isLoading,
      isHorizontal = _ref.isHorizontal,
      isReadOnly = _ref.isReadOnly,
      labelName = _ref.labelName,
      labelComponent = _ref.labelComponent,
      labelSize = _ref.labelSize,
      onBlur = _ref.onBlur,
      _onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      placeholder = _ref.placeholder,
      rows = _ref.rows,
      state = _ref.state,
      value = _ref.value,
      props = _objectWithoutProperties(_ref, ['autoComplete', 'autoFocus', 'children', 'className', 'color', 'helpText', 'inputSize', 'id', 'inputProps', 'isDisabled', 'isLoading', 'isHorizontal', 'isReadOnly', 'labelName', 'labelComponent', 'labelSize', 'onBlur', 'onChange', 'onFocus', 'placeholder', 'rows', 'state', 'value']);

  return React.createElement(
    Field,
    _extends({ id: id, isHorizontal: isHorizontal }, props),
    (labelName || labelComponent) && React.createElement(
      FieldLabel,
      { isHorizontal: isHorizontal, isNormal: true, size: labelSize },
      labelName || labelComponent
    ),
    React.createElement(
      FieldBody,
      null,
      React.createElement(
        Field,
        { color: color, helpText: helpText },
        React.createElement(
          FieldControl,
          { color: color, isLoading: isLoading },
          React.createElement(TextareaAutosize, _extends({
            'aria-label': labelName,
            autoComplete: autoComplete,
            autoFocus: autoFocus,
            className: classNames('textarea', (_classNames = {}, _classNames['is-' + color] = color, _classNames['is-' + inputSize] = inputSize, _classNames['is-' + state] = state, _classNames[className] = Boolean(className), _classNames)),
            disabled: isDisabled,
            onBlur: onBlur,
            onChange: function onChange(e) {
              return _onChange && _onChange(e.target.value, e);
            },
            onFocus: onBlur,
            placeholder: placeholder,
            readOnly: isReadOnly,
            rows: rows,
            value: value
          }, inputProps))
        )
      )
    )
  );
};

TextAreaField.propTypes = process.env.NODE_ENV !== "production" ? {
  /** Set an autocomplete attribute on the field */
  autoComplete: PropTypes.string,
  /** Automatically set focus to the field */
  autoFocus: PropTypes.bool,
  children: PropTypes.node,
  className: PropTypes.string,
  /** Color of input field. */
  color: sharedPropTypes.color,
  /** Displays help text */
  helpText: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  inputProps: PropTypes.object,
  /** The label that appears above the input */
  labelComponent: PropTypes.element,
  /** The label that appears above the input */
  labelName: PropTypes.string,
  /** Size of the label field */
  labelSize: sharedPropTypes.size,
  /** ID for the input field */
  id: PropTypes.string,
  /** Size of the input field */
  inputSize: sharedPropTypes.size,
  /** Disable the input field */
  isDisabled: PropTypes.bool,
  /** Input field is loading */
  isLoading: PropTypes.bool,
  /** Input field is horizontal */
  isHorizontal: PropTypes.bool,
  /** Input field is read only */
  isReadOnly: PropTypes.bool,
  /** Function to invoke on blur */
  onBlur: PropTypes.func,
  /** Function to invoke on change */
  onChange: PropTypes.func,
  /** Function to invoke on focus */
  onFocus: PropTypes.func,
  /** Placeholder of the input */
  placeholder: PropTypes.string,
  /** Minimum number of rows */
  rows: PropTypes.number,
  /** State of field */
  state: sharedPropTypes.state,
  /** Value of the input */
  value: PropTypes.string
} : {};

TextAreaField.defaultProps = {
  autoComplete: null,
  autoFocus: false,
  children: null,
  className: null,
  color: null,
  helpText: null,
  labelComponent: null,
  labelName: null,
  labelSize: null,
  id: null,
  inputProps: {},
  inputSize: null,
  isDisabled: false,
  isLoading: false,
  isHorizontal: false,
  isReadOnly: false,
  onBlur: null,
  onChange: null,
  onFocus: null,
  placeholder: null,
  rows: 3,
  state: null,
  value: undefined
};

export default TextAreaField;